======================
Gunicorn - wsgi server
======================


.. image:: _static/gunicorn.png

Gunicorn 'Green Unicorn' is a Python WSGI HTTP Server for UNIX. It's a pre-fork
worker model ported from Ruby's Unicorn project. The Gunicorn server is broadly
compatible with various web frameworks, simply implemented, light on server
resources, and fairly speedy.

Features
--------

* Natively supports WSGI, Django, and Paster
* Automatic worker process management
* Simple Python configuration
* Multiple worker configurations
* Various server hooks for extensibility
* Compatible with Python 2.x >= 2.6 or 3.x >= 3.1


.. note::
    main Gunicorn website on http://gunicorn.org 


.. note::
    gunicorn source code is hosted on `Github <http://github.com/benoitc/gunicorn.git>`_



Contents
--------

.. toctree::
    :titlesonly:

    install
    run
    configure
    deploy
    design
    signals
    community
    faq
    news
